module WeatherModel
  module Storer
    require 'active_record'
    require 'ohm'
    require "ohm/expire"

    class Mysql < ::ActiveRecord::Base
      after_save :update_ohm
      def self.use_settings settings
        self.table_name = settings[:table_name]
        Ohm.use_settings settings
      end

      class Ohm < ::Ohm::Model
        include ::Ohm::Expire
        def self.use_settings settings

          attribute :mysql_id
          attribute :updated_at
          index :mysql_id
          settings[:schema].keys.each { |attr|
            attribute attr
          }
          [:index, :unique, :expire, :son, :dad].each do |option|
            attrs = settings[:options][option]
            attrs.is_a?(Array) ?
              attrs.each{ |attr| method(option).call(attr) if attr } :
              method(option).call(attrs) if attrs
          end
        end

      private
        def self.son his_son # input like :Post
          # collection :posts, :Post
          collection(his_son.to_s.underscore.pluralize.to_sym, his_son) if his_son && SourceSchema.const_defined?(his_son)
        end

        def self.dad his_dad # input like :Post
          # reference :post, :Post
          reference(his_dad.to_s.underscore.to_sym, his_dad ) if his_dad && SourceSchema.const_defined?(his_dad)
        end
      end

    private
      def update_ohm
        ohm_attrs = self.attributes.except('created_at', 'id').merge(mysql_id: id)
        # find 找不到 会自动生成
        ohm_obj = Ohm.find(mysql_id: id).first.update(ohm_attrs)
        # rescue  Ohm::UniqueIndexViolation mysql_id should be unique
      end   
    end


   
  end
end
