require "spec_helper"
require 'active_record'
require "ohm"

RSpec.describe WeatherModel do
  include WeatherModel
  before do
    # start an ohm
    Ohm.redis = Redic.new("redis://127.0.0.1:6379")
    # run migration
    Dir[File.dirname(__FILE__) + '/../db/migrate/*.rb'].each { |file| require  file }
    ActiveRecord::Base.establish_connection(
      :adapter => 'sqlite3',
      :database => 'weather-model-test.sqlite3'
    )
    ActiveRecord::Migration[5.0].subclasses.each do |migrate|
      migrate.migrate(:up) 
    end
  end

  it "has a version number" do
    expect(WeatherModel::VERSION).not_to be nil
  end

  it 'Forecast' do
    mysql_obj = Forecast::ShanghaiTen.create({
          datetime: '2017-05-16',
          cityname: 'shanghai',
          temp_high: '100',
          temp_low: '0',
          weather_text: '酷热严寒',
          weather_pic: 'http://xxx.com',
          win_dir: '东南西北风',
          win_speed: '1级',
        })
    expect(Forecast::ShanghaiTen.count).to eq(1)
    expect(Forecast::ShanghaiTen::Ohm.all.count).to eq(1)

    expect(Forecast::ShanghaiTen::Ohm.all.first.temp_low).to eq(mysql_obj.temp_low.to_s)
    # 'ohm 对象 同步 mysql对象更新'
    mysql_obj.update(temp_low: 99)
    expect(Forecast::ShanghaiTen::Ohm.all.first.temp_low).to eq('99'), 'ohm 对象 同步 mysql对象更新'
    # ttl 失败
    # p Forecast::ShanghaiTen::Ohm.all.to_a.map(&:get_ttl)

  end

  after do
    ActiveRecord::Migration[5.0].subclasses.each do |migrate|
      migrate.migrate(:down) 
    end 
  end

end
